;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  db.scm (this assumes db0.scm has been loaded)
;;   Loading this library opens a connection to the database
;;   which stays open.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Default database connection
;;  Here we specify the default database connection
;;  This is a connection to a database which is
;;  initialized when the servlet container starts up
;;  and which can be shutdown nicely or abruptly
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


(define (open-dbconnection)
 (case database
  ((hsqldb)
   (let (
         (host/db "jdbc:hsqldb:database/data2")  ;; this corresponds to an "in process" database
         (user "sa") 
         (pw ""))
     (connect host/db user pw)))
  ((mysql)
   (let ((host  "jscheme.cs.brandeis.edu") ;; we assume the database is running locally
         (port "3306")
         (db "cs98b03")
         (user "guest") 
         (pw "abc777"))
     (java.sql.DriverManager.getConnection
          {jdbc:mysql://[host]:[port]/[db]} user pw)))
 ))


(define dbconnection     ;; this is defined so that if db.scm is reloaded it doesn't reopen the connection
  (tryCatch dbconnection 
     (lambda(e) (open-dbconnection))))

;; this sends a query along the already open connection.
(define dbquery 
    (lambda (Q)
      (if (.isClosed dbconnection) (set! dbconnection (open-dbconnection)))
      (tryCatch
        (handlequery dbconnection Q)
        (lambda(e) `((,e))))))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Here are some procedures that use the dbquery to implement useful
;; servlet operations
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

 (define (counter name)  ;; here is a simple counter
   (define (newcounter name) 
     (let ((N (dbquery {select counter from mycounter where  name=[(toSQL name)]})))
       (= (length N) 1)))
   (if (newcounter name)
       (dbquery {insert into mycounter values([(toSQL name)],1)})
       (dbquery {update mycounter set counter=counter + 1 where name=[(toSQL name)]}))
   (first (second (dbquery {select counter from mycounter where  name=[(toSQL name)]}))))
